# (Unofficial) PERIN: Permutation-invariant Semantic Parsing

Unofficial package for the PERIN parser: https://github.com/ufal/perin

Intended for easy installation and faster batching.

## Installation

```bash
pip install perin_parser
```


## License

```
Copyright 2020 Institute of Formal and Applied Linguistics, Faculty of
Mathematics and Physics, Charles University, Czech Republic.

This Source Code Form is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at http://mozilla.org/MPL/2.0/.
```

